@@ -25,13 +25,15 @@
     un-marshalling untrusted data can result in arbitrary code execution).
 """
 import marshal
-import logging
 import os.path
 import socket
 import struct
 import fcntl
+import json
 
-from six.moves import asyncio
+from . import asyncio
+
+from .log_utils import logger
 
 HDRLEN = 4
 
@@ -42,21 +44,36 @@ class IPCError(Exception):
 
 class _IPC(object):
     def _unpack(self, data):
+
+        if data is None:
+            raise IPCError("received data is None")
+        try:
+            return json.loads(data.decode('utf-8')), True
+        except ValueError:
+            pass
+
         try:
             assert len(data) >= HDRLEN
             size = struct.unpack("!L", data[:HDRLEN])[0]
             assert size >= len(data[HDRLEN:])
-            return self._unpack_body(data[HDRLEN:HDRLEN + size])
+            return self._unpack_body(data[HDRLEN:HDRLEN + size]), False
         except AssertionError:
             raise IPCError(
                 "error reading reply!"
                 " (probably the socket was disconnected)"
             )
 
-    def _unpack_body(self, body):
+    @staticmethod
+    def _unpack_body(body):
         return marshal.loads(body)
 
-    def _pack(self, msg):
+    @staticmethod
+    def _pack_json(msg):
+        json_obj = json.dumps(msg)
+        return json_obj.encode('utf-8')
+
+    @staticmethod
+    def _pack(msg):
         msg = marshal.dumps(msg)
         size = struct.pack("!L", len(msg))
         return size + msg
@@ -71,7 +88,7 @@ class _ClientProtocol(asyncio.Protocol, _IPC):
     2. The message is sent to the server with .send(msg), which closes the
     connection once the message is sent.
 
-    3. The client then recieves data from the server until the server closes
+    3. The client then receives data from the server until the server closes
     the connection, signalling that all the data has been sent.
 
     4. When the server sends on EOF, the data is unpacked and stored to the
@@ -82,13 +99,18 @@ class _ClientProtocol(asyncio.Protocol, _IPC):
         self.recv = b''
         self.reply = asyncio.Future()
 
-    def send(self, msg):
-        self.transport.write(self._pack(msg))
+    def send(self, msg, is_json=False):
+        if is_json:
+            send_data = self._pack_json(msg)
+        else:
+            send_data = self._pack(msg)
+
+        self.transport.write(send_data)
+
         try:
             self.transport.write_eof()
         except AttributeError:
-            log = logging.getLogger('qtile')
-            log.exception('Swallowing AttributeError due to asyncio bug!')
+            logger.exception('Swallowing AttributeError due to asyncio bug!')
 
     def data_received(self, data):
         self.recv += data
@@ -96,7 +118,7 @@ class _ClientProtocol(asyncio.Protocol, _IPC):
     def eof_received(self):
         # The server sends EOF when there is data ready to be processed
         try:
-            data = self._unpack(self.recv)
+            data, _ = self._unpack(self.recv)
         except IPCError as e:
             self.reply.set_exception(e)
         else:
@@ -111,20 +133,20 @@ class _ClientProtocol(asyncio.Protocol, _IPC):
 
 
 class Client(object):
-    def __init__(self, fname):
+    def __init__(self, fname, is_json=False):
         self.fname = fname
         self.loop = asyncio.get_event_loop()
+        self.is_json = is_json
 
     def send(self, msg):
         client_coroutine = self.loop.create_unix_connection(_ClientProtocol, path=self.fname)
 
         try:
-
             _, client_proto = self.loop.run_until_complete(client_coroutine)
         except OSError:
             raise IPCError("Could not open %s" % self.fname)
 
-        client_proto.send(msg)
+        client_proto.send(msg, is_json=self.is_json)
 
         try:
             self.loop.run_until_complete(asyncio.wait_for(client_proto.reply, timeout=10))
@@ -140,8 +162,8 @@ class Client(object):
 class _ServerProtocol(asyncio.Protocol, _IPC):
     """IPC Server Protocol
 
-    1. The server is initalized with a handler callback function for evaluating
-    incoming queries and a log.
+    1. The server is initialized with a handler callback function for evaluating
+    incoming queries.
 
     2. Once the connection is made, the server initializes a data store for
     incoming data.
@@ -152,49 +174,55 @@ class _ServerProtocol(asyncio.Protocol, _IPC):
     point the server then unpacks the data and runs it through the handler.
     The result is returned to the client and the connection is closed.
     """
-    def __init__(self, handler, log):
+    def __init__(self, handler):
         asyncio.Protocol.__init__(self)
         self.handler = handler
-        self.log = log
+        self.transport = None
+        self.data = None
 
     def connection_made(self, transport):
         self.transport = transport
-        self.log.info('Connection made to server')
+        logger.info('Connection made to server')
         self.data = b''
 
     def data_received(self, recv):
-        self.log.info('Data recieved by server')
+        logger.info('Data received by server')
         self.data += recv
 
     def eof_received(self):
-        self.log.info('EOF recieved by server')
+        logger.info('EOF received by server')
         try:
-            req = self._unpack(self.data)
+            req, is_json = self._unpack(self.data)
         except IPCError:
-            self.log.info('Invalid data received, closing connection')
+            logger.warn('Invalid data received, closing connection')
             self.transport.close()
             return
         finally:
             self.data = None
 
         if req[1] == 'restart':
-            self.log.info('Closing connection on restart')
+            logger.info('Closing connection on restart')
             self.transport.write_eof()
 
         rep = self.handler(req)
-        result = self._pack(rep)
-        self.log.info('Sending result on receive EOF')
+
+        if is_json:
+            result = self._pack_json(rep)
+        else:
+            result = self._pack(rep)
+
+        logger.info('Sending result on receive EOF')
         self.transport.write(result)
-        self.log.info('Closing connection on receive EOF')
+        logger.info('Closing connection on receive EOF')
         self.transport.write_eof()
 
 
 class Server(object):
-    def __init__(self, fname, handler):
-        self.log = logging.getLogger('qtile')
+    def __init__(self, fname, handler, loop):
         self.fname = fname
         self.handler = handler
-        self.loop = asyncio.get_event_loop()
+        self.loop = loop
+        self.server = None
 
         if os.path.exists(fname):
             os.unlink(fname)
@@ -209,13 +237,13 @@ class Server(object):
         self.sock.bind(self.fname)
 
     def close(self):
-        self.log.info('Stopping server on server close')
+        logger.info('Stopping server on server close')
         self.server.close()
         self.sock.close()
 
     def start(self):
-        serverprotocol = _ServerProtocol(self.handler, self.log)
+        serverprotocol = _ServerProtocol(self.handler)
         server_coroutine = self.loop.create_unix_server(lambda: serverprotocol, sock=self.sock, backlog=5)
 
-        self.log.info('Starting server')
+        logger.info('Starting server')
         self.server = self.loop.run_until_complete(server_coroutine)
