@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright (c) 2011 Florian Mounier
 # Copyright (c) 2012, 2015 Tycho Andersen
 # Copyright (c) 2013 Tao Sauvage
@@ -22,7 +23,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-# -*- coding: utf-8 -*-
 """
 Slice layout. Serves as example of delegating layouts (or sublayouts)
 """
@@ -104,8 +104,8 @@ class Slice(Delegate):
         ("fallback", Max(), "Fallback layout"),
     ]
 
-    def __init__(self, side, width, **config):
-        Delegate.__init__(self, width=width, side=side, **config)
+    def __init__(self, **config):
+        Delegate.__init__(self, **config)
         self.add_defaults(Slice.defaults)
         self.match = {
             'wname': self.wname,
