@@ -159,6 +159,7 @@ class MonadTall(Layout):
             "(one of ``MonadTall._left`` or ``MonadTall._right``)"),
         ("change_ratio", .05, "Resize ratio"),
         ("change_size", 20, "Resize change in pixels"),
+        ("new_at_current", False, "Place new windows at the position of the active window."),
     ]
 
     def __init__(self, **config):
@@ -209,7 +210,8 @@ class MonadTall(Layout):
 
     def add(self, client):
         "Add client to layout"
-        self.clients.insert(self.focused + 1, client)
+        new_index = self.focused + (0 if self.new_at_current else 1)
+        self.clients.insert(new_index, client)
         self.do_normalize = True
 
     def remove(self, client):
@@ -296,9 +298,14 @@ class MonadTall(Layout):
             client.hide()
             return
 
+        # determine focus border-color
+        if client.has_focus:
+            px = self.group.qtile.colorPixel(self.border_focus)
+        else:
+            px = self.group.qtile.colorPixel(self.border_normal)
+
         # single client - fullscreen
         if len(self.clients) == 1:
-            px = self.group.qtile.colorPixel(self.border_focus)
             client.place(
                 self.group.screen.dx,
                 self.group.screen.dy,
@@ -313,12 +320,6 @@ class MonadTall(Layout):
 
         cidx = self.clients.index(client)
 
-        # determine focus border-color
-        if cidx == self.focused:
-            px = self.group.qtile.colorPixel(self.border_focus)
-        else:
-            px = self.group.qtile.colorPixel(self.border_normal)
-
         # calculate main/secondary column widths
         width_main = int(self.group.screen.dwidth * self.ratio)
         width_shared = self.group.screen.dwidth - width_main
