@@ -111,7 +111,7 @@ class Qtile(command.CommandObject):
 
         # Find the modifier mask for the numlock key, if there is one:
         nc = self.conn.keysym_to_keycode(xcbq.keysyms["Num_Lock"])
-        self.numlockMask = xcbq.ModMasks[self.conn.get_modifier(nc)]
+        self.numlockMask = xcbq.ModMasks.get(self.conn.get_modifier(nc), 0)
         self.validMask = ~(self.numlockMask | xcbq.ModMasks["lock"])
 
         # Because we only do Xinerama multi-screening,
@@ -930,7 +930,8 @@ class Qtile(command.CommandObject):
                 [xcffib.xproto.StackMode.Above]
             )
 
-        if self.windowMap.get(wnd):
+        window = self.windowMap.get(wnd)
+        if window and not window.window.get_property('QTILE_INTERNAL'):
             self.currentGroup.focus(self.windowMap.get(wnd), False)
             self.windowMap.get(wnd).focus(False)
 
@@ -1091,6 +1092,7 @@ class Qtile(command.CommandObject):
         self.currentScreen = self.screens[n]
         if old != self.currentScreen:
             hook.fire("current_screen_change")
+            old.group.layoutAll()
             self.currentGroup.focus(self.currentWindow, warp)
 
     def moveToGroup(self, group):
@@ -1154,21 +1156,21 @@ class Qtile(command.CommandObject):
         def f():
             func(*args)
             self.conn.flush()
-        self._eventloop.call_soon(f)
+        return self._eventloop.call_soon(f)
 
     def call_soon_threadsafe(self, func, *args):
         """ Another event loop proxy, see `call_soon`. """
         def f():
             func(*args)
             self.conn.flush()
-        self._eventloop.call_soon_threadsafe(f)
+        return self._eventloop.call_soon_threadsafe(f)
 
     def call_later(self, delay, func, *args):
         """ Another event loop proxy, see `call_soon`. """
         def f():
             func(*args)
             self.conn.flush()
-        self._eventloop.call_later(delay, f)
+        return self._eventloop.call_later(delay, f)
 
     def run_in_executor(self, func, *args):
         """ A wrapper for running a function in the event loop's default
@@ -1240,7 +1242,7 @@ class Qtile(command.CommandObject):
                 return " ".join((["%-{0:d}s".format(max_col_size + 2) for max_col_size in self.max_col_size])) + "\n", len(self.max_col_size)
 
             def expandlist(self, list, n):
-                if list:
+                if not list:
                     return ["-" * max_col_size for max_col_size in self.max_col_size]
                 n -= len(list)
                 if n > 0:
@@ -1256,7 +1258,7 @@ class Qtile(command.CommandObject):
         result.add([])
         rows = []
         for (ks, kmm), k in self.keyMap.items():
-            if k.commands:
+            if not k.commands:
                 continue
             name = ", ".join(xcbq.rkeysyms.get(ks, ("<unknown>", )))
             modifiers = ", ".join(utils.translate_modifiers(kmm))
@@ -1817,3 +1819,8 @@ class Qtile(command.CommandObject):
         malloc_dump = os.path.join(cache_directory, "qtile_tracemalloc.dump")
         tracemalloc.take_snapshot().dump(malloc_dump)
         return [True, malloc_dump]
+
+    def cmd_run_extention(self, cls):
+        """Extentions should run from command run()"""
+        c = cls(self)
+        c.run()
