@@ -44,14 +44,15 @@ def safe_import(module_name, class_name):
         module = importlib.import_module(module_name, package)
         globals()[class_name] = getattr(module, class_name)
     except ImportError as error:
-        logger.warning("Can't Import Widget: '%s.%s', %s", module_name, class_name, error)
+        logger.warning("Unmet dependencies for optional Widget: '%s.%s', %s",
+                       module_name, class_name, error)
         logger.debug("%s", traceback.format_exc())
 
 
 safe_import(".backlight", "Backlight")
 safe_import(".battery", ["Battery", "BatteryIcon"])
 safe_import(".clock", "Clock")
-safe_import(".currentlayout", "CurrentLayout")
+safe_import(".currentlayout", ["CurrentLayout", "CurrentLayoutIcon"])
 safe_import(".currentscreen", "CurrentScreen")
 safe_import(".debuginfo", "DebugInfo")
 safe_import(".graph", ["CPUGraph", "MemoryGraph", "SwapGraph", "NetGraph",
@@ -83,6 +84,7 @@ safe_import(".canto", "Canto")
 safe_import(".mpriswidget", "Mpris")
 safe_import(".mpris2widget", "Mpris2")
 safe_import(".mpdwidget", "Mpd")
+safe_import(".mpd2widget", "Mpd2")
 safe_import(".yahoo_weather", "YahooWeather")
 safe_import(".bitcoin_ticker", "BitcoinTicker")
 safe_import(".wlan", "Wlan")
@@ -95,3 +97,4 @@ safe_import(".wallpaper", "Wallpaper")
 safe_import(".check_updates", "CheckUpdates")
 safe_import(".moc", "Moc")
 safe_import(".memory", "Memory")
+safe_import(".idlerpg", "IdleRPG")
