@@ -153,12 +153,13 @@ class _Widget(command.CommandObject, configurable.Configurable):
         if horizontal:
             if not self.orientations & ORIENTATION_HORIZONTAL:
                 raise confreader.ConfigError(
-                    "The widget is not compatible with the orientation of the "
-                    "bar."
+                    self.__class__.__name__ +
+                    " is not compatible with the orientation of the bar."
                 )
         elif not self.orientations & ORIENTATION_VERTICAL:
             raise confreader.ConfigError(
-                "The widget is not compatible with the orientation of the bar."
+                self.__class__.__name__ +
+                " is not compatible with the orientation of the bar."
             )
 
     def timer_setup(self):
@@ -467,7 +468,8 @@ class ThreadedPollText(InLoopPollText):
         def worker():
             try:
                 text = self.poll()
-                self.qtile.call_soon_threadsafe(self.update, text)
+                if self.qtile is not None:
+                    self.qtile.call_soon_threadsafe(self.update, text)
             except:
                 logger.exception("problem polling to update widget %s", self.name)
         # TODO: There are nice asyncio constructs for this sort of thing, I
