@@ -22,7 +22,7 @@
 # SOFTWARE.
 
 from time import time
-from datetime import datetime
+from datetime import datetime, timedelta
 from contextlib import contextmanager
 from . import base
 
@@ -39,9 +39,7 @@ def tz(the_tz):
         del os.environ['TZ']
 
 class Clock(base.InLoopPollText):
-    """
-        A simple but flexible text-based clock.
-    """
+    """A simple but flexible text-based clock"""
     orientations = base.ORIENTATION_HORIZONTAL
     defaults = [
         ('format', '%H:%M', 'A Python datetime format string'),
@@ -50,21 +48,21 @@ class Clock(base.InLoopPollText):
             'e.g. "US/Central" (or anything in /usr/share/zoneinfo). None means '
             'the default timezone.')
     ]
+    DELTA = timedelta(seconds=0.5)
+
     def __init__(self, **config):
         base.InLoopPollText.__init__(self, **config)
         self.add_defaults(Clock.defaults)
 
     def tick(self):
         self.update(self.poll())
-        ts = time()
-        return self.update_interval - ts % self.update_interval
+        return self.update_interval - time() % self.update_interval
 
+    # adding .5 to get a proper seconds value because glib could
+    # theoreticaly call our method too early and we could get something
+    # like (x-1).999 instead of x.000
     def _get_time(self):
-        ts = time()
-        # adding .5 to get a proper seconds value because glib could
-        # theoreticaly call our method too early and we could get something
-        # like (x-1).999 instead of x.000
-        return datetime.fromtimestamp(int(ts + .5)).strftime(self.format)
+        return (datetime.now() + self.DELTA).strftime(self.format)
 
     def poll(self):
         # We use None as a sentinel here because C's strftime defaults to UTC
