@@ -22,16 +22,12 @@
 
 from .. import hook, bar, layout
 from . import base
-import logging
 
 class DebugInfo(base._TextBox):
-    """
-        Displays debugging infos about selected window
-    """
+    """Displays debugging infos about selected window"""
     orientations = base.ORIENTATION_HORIZONTAL
 
     def __init__(self, **config):
-        self.log = logging.getLogger('qtile')
         base._TextBox.__init__(self, text=" ", width=bar.CALCULATED, **config)
 
     def _configure(self, qtile, bar):
