@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright (c) 2015 David R. Andersen
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -18,27 +19,25 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-# -*- coding: utf-8 -*-
-#
-###################################################################
-
 from . import base
+from libqtile.log_utils import logger
+
 import imaplib
 import re
 import keyring
 
 class ImapWidget(base.ThreadedPollText):
-    """
-    This widget will scan one of your imap email boxes and report
-    the number of unseen messages present.  I've configured it to
-    only work with imap with ssl. Your password is obtained from
-    the Gnome Keyring.
+    """Email IMAP widget
 
-    Writing your password to the keyring initially is as simple as
-    (changing out <userid> and <password> for your userid and password):
+    This widget will scan one of your imap email boxes and report the number of
+    unseen messages present.  I've configured it to only work with imap with
+    ssl. Your password is obtained from the Gnome Keyring.
 
-    1) create the file ~/.local/share/python_keyring/keyringrc.cfg
-       with the following contents:
+    Writing your password to the keyring initially is as simple as (changing
+    out <userid> and <password> for your userid and password):
+
+    1) create the file ~/.local/share/python_keyring/keyringrc.cfg with the
+       following contents:
 
        [backend]
        default-keyring=keyring.backends.Gnome.Keyring
@@ -53,12 +52,11 @@ class ImapWidget(base.ThreadedPollText):
        password = <password>
        keyring.set_password('imapwidget', user, password)
 
-    mbox names must include the path to the mbox (except for the
-    default INBOX).  So, for example if your mailroot is ~/Maildir,
-    and you want to look at the mailbox at HomeMail/fred, the mbox
-    setting would be: mbox='"~/Maildir/HomeMail/fred"'.  Note the
-    nested sets of quotes! Labels can be whatever you choose, of
-    course.
+    mbox names must include the path to the mbox (except for the default
+    INBOX).  So, for example if your mailroot is ~/Maildir, and you want to
+    look at the mailbox at HomeMail/fred, the mbox setting would be:
+    mbox='"~/Maildir/HomeMail/fred"'.  Note the nested sets of quotes! Labels
+    can be whatever you choose, of course.
     """
     orientations = base.ORIENTATION_HORIZONTAL
     defaults = [
@@ -75,8 +73,7 @@ class ImapWidget(base.ThreadedPollText):
         if password is not None:
             self.password = password
         else:
-            self.log.critical('Gnome Keyring Error')
-            return ('Gnome Keyring Error',)
+            logger.critical('Gnome Keyring Error')
 
     def poll(self):
         im = imaplib.IMAP4_SSL(self.server, 993)
