@@ -35,8 +35,8 @@ displayed instead.
 
 To execute a software:
  - ('thunderbird', 'thunderbird -safe-mode', 'launch thunderbird in safe mode')
-To execute a python command in qtile, begin with by 'qsh:'
- - ('logout', 'qsh:self.qtile.cmd_shutdown()', 'logout from qtile')
+To execute a python command in qtile, begin with by 'qshell:'
+ - ('logout', 'qshell:self.qtile.cmd_shutdown()', 'logout from qtile')
 
 
 """
@@ -44,6 +44,7 @@ To execute a python command in qtile, begin with by 'qsh:'
 from __future__ import division
 
 from libqtile import bar
+from libqtile.log_utils import logger
 from libqtile.widget import base
 
 import os.path
@@ -52,8 +53,16 @@ from xdg.IconTheme import getIconPath
 
 
 class LaunchBar(base._Widget):
-    """
-    A widget that display icons to launch the associated command.
+    """A widget that display icons to launch the associated command
+
+    Parameters
+    ==========
+    progs :
+        a list of tuples ``(software_name, command_to_execute, comment)``, for
+        example::
+
+            ('thunderbird', 'thunderbird -safe-mode', 'launch thunderbird in safe mode')
+            ('logout', 'qshell:self.qtile.cmd_shutdown()', 'logout from qtile')
     """
     orientations = base.ORIENTATION_HORIZONTAL
     defaults = [
@@ -63,13 +72,6 @@ class LaunchBar(base._Widget):
     ]
 
     def __init__(self, progs=None, width=bar.CALCULATED, **config):
-        """
-        @progs: a list of tuple (software_name, command_to_execute, comment)
-        for example:
-        ('thunderbird', 'thunderbird -safe-mode', 'launch thunderbird in safe\
-        mode')
-        ('logout', 'qsh:self.qtile.cmd_shutdown()', 'logout from qtile')
-        """
         base._Widget.__init__(self, width, **config)
         if progs is None:
             progs = []
@@ -96,9 +98,9 @@ class LaunchBar(base._Widget):
         """ Create image structures for each icon files. """
         for img_name, iconfile in self.icons_files.items():
             if iconfile is None:
-                self.qtile.log.warning('No icon found for application "' +
-                                       img_name + '" (' + str(iconfile) + ')' +
-                                       ' switch to text mode')
+                logger.warning(
+                    'No icon found for application "%s" (%s) switch to text mode',
+                    img_name, iconfile)
                 # if no icon is found and no default icon was set, we just
                 # print the name, based on a textbox.
                 textbox = base._TextBox()
@@ -121,9 +123,8 @@ class LaunchBar(base._Widget):
                 try:
                     img = cairocffi.ImageSurface.create_from_png(iconfile)
                 except cairocffi.Error:
-                    self.qtile.log.exception('Error loading icon for ' +
-                                             'application "' + img_name + '" (' +
-                                             iconfile + ')')
+                    logger.exception('Error loading icon for application "%s" (%s)',
+                        img_name, iconfile)
                     return
 
             input_width = img.get_width()
@@ -145,7 +146,7 @@ class LaunchBar(base._Widget):
     def _lookup_icon(self, name):
         """ Search for the icon corresponding to one command. """
         self.icons_files[name] = None
-        # if the software_name is directly an abslolute path icon file
+        # if the software_name is directly an absolute path icon file
         if os.path.isabs(name):
             # name start with '/' thus it's an absolute path
             root, ext = os.path.splitext(name)
@@ -172,7 +173,7 @@ class LaunchBar(base._Widget):
             self._lookup_icon(name)
 
     def get_icon_in_position(self, x, y):
-        """ Retreive the wich icon is clicked according to its position. """
+        """ Determine which icon is clicked according to its position. """
         for i in self.progs:
             if x < (self.icons_offsets[i] +
                     self.icons_widths[self.progs[i]['name']] +
@@ -185,7 +186,7 @@ class LaunchBar(base._Widget):
             icon = self.get_icon_in_position(x, y)
             if icon is not None:
                 cmd = self.progs[icon]['cmd']
-                if cmd.startswith('qsh:'):
+                if cmd.startswith('qshell:'):
                     exec(cmd[4:].lstrip())
                 else:
                     self.qtile.cmd_spawn(cmd)
@@ -218,5 +219,5 @@ class LaunchBar(base._Widget):
 
     def calculate_length(self):
         """ Compute the width of the widget according to each icon width. """
-        return sum([self.icons_widths[prg['name']] for prg in self.progs.values()]) \
+        return sum(self.icons_widths[prg['name']] for prg in self.progs.values()) \
             + self.padding * (len(self.progs) + 1)
