@@ -48,55 +48,35 @@ from .. import utils, pangocffi
 from . import base
 from libqtile.log_utils import logger
 
+
 class Mpd(base.ThreadPoolText):
-    """A widget for the Music Player Daemon (MPD)
-
-    Initialize the widget with the following parameters
-
-    Parameters
-    ==========
-    host :
-        host to connect to
-    port :
-        port to connect to
-    password :
-        password to use
-    fmt_playing :
-        format string to display when playing/paused
-    fmt_stopped :
-        format strings to display when stopped
-    msg_nc :
-        which message to show when we're not connected
-    do_color_progress :
-        whether to indicate progress in song by altering message color
-    width :
-        A fixed width, or bar.CALCULATED to calculate the width automatically
-        (which is recommended).
-    """
+    """A widget for the Music Player Daemon (MPD)"""
     orientations = base.ORIENTATION_HORIZONTAL
     defaults = [
+        ("host", "localhost", "Host to connect to, can be either an IP "
+                              "address or a UNIX socket path"),
+        ("port", 6600, "Port to connect to"),
+        ("password", None, "Password to use"),
+        ("fmt_playing", "%a - %t [%v%%]", "Format string to display when "
+                                          "playing/paused"),
+        ("fmt_stopped", "Stopped [%v%%]", "Format strings to display when "
+                                          "stopped"),
+        ("msg_nc", "Mpd off", "Which message to show when we're not "
+                              "connected"),
+        ("do_color_progress", True, "Whether to indicate progress in song by "
+                                    "altering message color"),
         ("foreground_progress", "ffffff", "Foreground progress colour"),
-        ('reconnect', False, 'attempt to reconnect if initial connection failed'),
-        ('reconnect_interval', 1, 'Time to delay between connection attempts.'),
-        ('update_interval', 0.5, 'Update Time in seconds.')
+        ("reconnect", False, "Attempt to reconnect if initial connection failed"),
+        ("reconnect_interval", 1, "Time to delay between connection attempts."),
+        ("update_interval", 0.5, "Update Time in seconds.")
     ]
 
-    # TODO: have this use our config framework
-    def __init__(self, host='localhost', port=6600,
-                 password=False, fmt_playing="%a - %t [%v%%]",
-                 fmt_stopped="Stopped [%v%%]", msg_nc='Mpd off',
-                 do_color_progress=True, **config):
-        super(Mpd, self).__init__(msg_nc, **config)
-        self.host = host
-        self.port = port
-        self.password = password
-        self.fmt_playing, self.fmt_stopped = fmt_playing, fmt_stopped
-        self.msg_nc = msg_nc
-        self.do_color_progress = do_color_progress
-        self.inc = 2
+    def __init__(self, **config):
+        super(Mpd, self).__init__('MPD Widget', **config)
         self.add_defaults(Mpd.defaults)
+        self.inc = 2
         self.client = mpd.MPDClient()
-        self.connected = False
+        self.connected = None
         self.stop = False
 
     def finalize(self):
@@ -137,6 +117,7 @@ class Mpd(base.ThreadPoolText):
                     self.client.disconnect()
                 except Exception:
                     pass
+                return False
 
         self.connected = True
         return True
@@ -263,17 +244,19 @@ class Mpd(base.ThreadPoolText):
             if self.status['state'] != 'stop':
                 text = self.do_format(self.fmt_playing)
 
-                if (self.do_color_progress and
-                        self.status and
-                        self.status.get('time')):
-                    elapsed, total = self.status['time'].split(':')
-                    percent = float(elapsed) / float(total)
-                    progress = int(percent * len(text))
-                    playing = '<span color="%s">%s</span>%s' % (
-                        utils.hex(self.foreground_progress),
-                        pangocffi.markup_escape_text(text[:progress]),
-                        pangocffi.markup_escape_text(text[progress:])
-                    )
+                if self.do_color_progress and self.status.get('time'):
+                    try:
+                        elapsed, total = self.status['time'].split(':')
+                        percent = float(elapsed) / float(total)
+                        progress = int(percent * len(text))
+                    except (ZeroDivisionError, ValueError):
+                        playing = pangocffi.markup_escape_text(text)
+                    else:
+                        playing = '<span color="{0}">{1}</span>{2}'.format(
+                            utils.hex(self.foreground_progress),
+                            pangocffi.markup_escape_text(text[:progress]),
+                            pangocffi.markup_escape_text(text[progress:])
+                        )
                 else:
                     playing = pangocffi.markup_escape_text(text)
             else:
@@ -288,19 +271,18 @@ class Mpd(base.ThreadPoolText):
         was_connected = self.connected
 
         if not self.connected:
-            if self.reconnect:
+            if self.connected is None or self.reconnect:
                 while not self.stop and not self.connect(quiet=True):
                     time.sleep(self.reconnect_interval)
             else:
                 return
 
         if self.stop:
-            return
+            return True
 
         if was_connected:
             try:
-                self.client.send_idle()
-                self.client.fetch_idle()
+                self.client.ping()
             except mpd.ConnectionError:
                 self.client.disconnect()
                 self.connected = False
@@ -318,7 +300,7 @@ class Mpd(base.ThreadPoolText):
         try:
             status = self.client.status()
             if button == 3:
-                if not status:
+                if not status or status.get('state', '') == 'stop':
                     self.client.play()
                 else:
                     self.client.pause()
