@@ -177,6 +177,8 @@ class TaskList(base._Widget, base.PaddingMixin, base.MarginMixin):
             window.group.focus(window, False)
             if window.floating:
                 window.cmd_bring_to_front()
+        elif window:
+            window.toggle_minimize()
 
     def get_window_icon(self, window):
         if not window.icons:
@@ -240,21 +242,30 @@ class TaskList(base._Widget, base.PaddingMixin, base.MarginMixin):
                 state = '_ '
             elif w.floating:
                 state = 'V '
+
             task = "%s%s" % (state, w.name if w and w.name else " ")
 
             if w.urgent:
                 border = self.urgent_border
+                text_color = border
             elif w is w.group.currentWindow:
                 border = self.border
+                text_color = border
             else:
                 border = self.background or self.bar.background
+                text_color = self.foreground
+
+            if self.highlight_method == 'text':
+                border = self.bar.background
+            else:
+                text_color = self.foreground
 
             bw = self.box_width(task)
             self.drawbox(
                 self.margin_x + offset,
                 task,
                 border,
-                self.foreground,
+                text_color,
                 rounded=self.rounded,
                 block=(self.highlight_method == 'block'),
                 width=(bw - self.margin_x * 2 - self.padding_x * 2),
