@@ -240,6 +240,10 @@ class _Window(command.CommandObject):
         fget=_float_getter("height")
     )
 
+    @property
+    def has_focus(self):
+        return self == self.qtile.currentWindow
+
     def updateName(self):
         try:
             self.name = self.window.get_name()
@@ -584,6 +588,12 @@ class _Window(command.CommandObject):
     def _select(self, name, sel):
         return None
 
+    def cmd_focus(self, warp=None):
+        """Focuses the window."""
+        if warp is None:
+            warp = self.qtile.config.cursor_warp
+        self.focus(warp=warp)
+
     def cmd_info(self):
         """Returns a dictionary of info for this object"""
         return self.info()
@@ -1029,6 +1039,17 @@ class Window(_Window):
                 self.x += group.screen.x
             group.add(self)
 
+    def toscreen(self, index=None):
+        """ Move window to a specified screen, or the current screen. """
+        if index is None:
+            screen = self.qtile.currentScreen
+        else:
+            try:
+                screen = self.qtile.screens[index]
+            except IndexError:
+                raise command.CommandError('No such screen: %d' % index)
+        self.togroup(screen.group.name)
+
     def match(self, wname=None, wmclass=None, role=None):
         """Match window against given attributes.
 
@@ -1273,6 +1294,24 @@ class Window(_Window):
         """
         self.togroup(groupName)
 
+    def cmd_toscreen(self, index=None):
+        """Move window to a specified screen.
+
+        If index is not specified, we assume the current screen
+
+        Examples
+        ========
+
+        Move window to current screen::
+
+            toscreen()
+
+        Move window to screen 0::
+
+            toscreen(0)
+        """
+        self.toscreen(index)
+
     def cmd_move_floating(self, dx, dy, curx, cury):
         """Move window by dx and dy"""
         self.tweak_float(dx=dx, dy=dy)
