@@ -450,6 +450,10 @@ class Window(object):
         if r:
             return self._propertyUTF8(r)
 
+        r = self.get_property(xcffib.xproto.Atom.WM_NAME, "UTF8_STRING")
+        if r:
+            return self._propertyUTF8(r)
+
         r = self.get_property(
             xcffib.xproto.Atom.WM_NAME,
             xcffib.xproto.GetPropertyType.Any
@@ -575,8 +579,10 @@ class Window(object):
         Arguments can be: x, y, width, height, border, sibling, stackmode
         """
         mask, values = ConfigureMasks(**kwargs)
-        # hack for negative numbers
-        values = [i & 0xffffffff for i in values]
+        # older versions of xcb pack everything into unsigned ints "=I"
+        # since 1.12, uses switches to pack things sensibly
+        if float(xcffib.__xcb_proto_version__) < 1.12:
+            values = [i & 0xffffffff for i in values]
         return self.conn.conn.core.ConfigureWindow(self.wid, mask, values)
 
     def set_attribute(self, **kwargs):
@@ -777,7 +783,7 @@ class Window(object):
         if q.root:
             root = Window(self.conn, q.root)
         if q.parent:
-            parent = Window(self.conn, q.root)
+            parent = Window(self.conn, q.parent)
         return root, parent, [Window(self.conn, i) for i in q.children]
 
 
